@@ -32,10 +32,6 @@ public:
 
 #endif // USE_EXCEPTIONS
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /*
  * Same as malloc, but prints error message and exits if malloc()
  * returns NULL.
@@ -96,8 +92,4 @@ extern void gMemReport(FILE *f);
  */
 extern char *copyString(const char *s);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
